pub struct FetchClient { /* private fields */ }Expand description
HTTP client wrapper for fetch bridge
Implementations
Sourceimpl FetchClient
impl FetchClient
Sourcepub fn new(cookies: Option<String>, base_url: Option<String>) -> Self
pub fn new(cookies: Option<String>, base_url: Option<String>) -> Self
Create a new fetch client with optional cookies and base URL
Sourcepub fn get_fetch_log(&self) -> Vec<String>
pub fn get_fetch_log(&self) -> Vec<String>
Get the list of all fetched URLs
Sourcepub fn fetch_sync(&self, url: String) -> Result<String>
pub fn fetch_sync(&self, url: String) -> Result<String>
Fetch a URL and return the response body as text This is a blocking call that executes the HTTP request synchronously